@@ -3,10 +3,13 @@
 #include <QDBusConnection>
 #include <QDBusMessage>
 #include <QDebug>
+#include <QNetworkInterface>
 
+#if 0
 #include <QNetworkConfigurationManager>
 #include <QNetworkConfiguration>
 #include <QNetworkSession>
+#endif
 
 
 WebAppNativeServices::WebAppNativeServices(QObject *parent) :
@@ -23,10 +26,21 @@ void WebAppNativeServices::exitAppView()
     bus.send(message);
 }
 
-using namespace QtMobility;
+
 
 void WebAppNativeServices::requestConnection()
 {
+    QDBusConnection bus = QDBusConnection::sessionBus();
+    QDBusMessage message = QDBusMessage::createMethodCall
+              ("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd", "connect");
+//    message.
+    QList<QVariant> args;
+    args << QVariant("[ANY]") << QVariant(0);
+    message.setArguments(args);
+    bool r = bus.send(message);
+
+#if 0
+
 
     QNetworkConfigurationManager manager;
     QNetworkConfiguration cfg = manager.defaultConfiguration();
@@ -34,8 +48,16 @@ void WebAppNativeServices::requestConnection()
     connect(m_session, SIGNAL(stateChanged(QNetworkSession::State)), this, SIGNAL(stateChanged(QNetworkSession::State)));
 
     m_session->open();
+
+#endif
 }
 
+#if 0
+
+
+
+using namespace QtMobility;
+
 
 QtMobility::QNetworkSession::State WebAppNativeServices::networkState()
 {
@@ -43,8 +65,15 @@ QtMobility::QNetworkSession::State WebAppNativeServices::networkState()
     return m_session->state();
 }
 
+#endif
+
 bool WebAppNativeServices::isOnline()
 {
-    QNetworkConfigurationManager manager;
-    return manager.isOnline();
+    QNetworkInterface wlan = QNetworkInterface::interfaceFromName("wlan0");
+    QNetworkInterface gprs = QNetworkInterface::interfaceFromName("gprs0");
+    if ((wlan.isValid() && wlan.flags().testFlag(QNetworkInterface::IsUp) ||
+         gprs.isValid() && gprs.flags().testFlag(QNetworkInterface::IsUp))) {
+        return true;
+    }
+    return false;
 }
