@@ -3,10 +3,14 @@
 
 #include <QObject>
 
+#if 0
 #include <QNetworkSession>
 
 using QtMobility::QNetworkSession;
 
+#endif
+
+
 class WebAppNativeServices : public QObject
 {
     Q_OBJECT
@@ -18,14 +22,23 @@ signals:
 public slots:
     void exitAppView();
     // initiates connection asynchronously
+
     void requestConnection();
+
+
+#if 0
     QtMobility::QNetworkSession::State networkState();
+#endif
     bool isOnline();
+
+#if 0
 signals:
+
     void stateChanged(QNetworkSession::State);
 
 private:
     QtMobility::QNetworkSession* m_session;
+#endif
 
 };
 
